@@ -134,7 +134,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -150,26 +150,26 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_cloudwatch
-import aws_cdk.aws_iam
-import aws_cdk.aws_iot
-import aws_cdk.aws_kinesis
-import constructs
+import aws_cdk.aws_cloudwatch as _aws_cdk_aws_cloudwatch_ceddda9d
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import aws_cdk.aws_iot as _aws_cdk_aws_iot_ceddda9d
+import aws_cdk.aws_kinesis as _aws_cdk_aws_kinesis_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class IotToKinesisStreams(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-iot-kinesisstreams.IotToKinesisStreams",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
+        iot_topic_rule_props: typing.Union[_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, typing.Dict[builtins.str, typing.Any]],
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-        existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
+        existing_stream_obj: typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.Stream] = None,
         kinesis_stream_props: typing.Any = None,
     ) -> None:
         '''
@@ -185,17 +185,7 @@ class IotToKinesisStreams(
         :summary: Constructs a new instance of the IotToKinesisFirehoseToS3 class.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
-                kinesis_stream_props: typing.Any = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__d28904177b510423b390da5905611b385d14e1350614ba786f1ee2611f052b7b)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = IotToKinesisStreamsProps(
@@ -209,25 +199,25 @@ class IotToKinesisStreams(
 
     @builtins.property
     @jsii.member(jsii_name="iotActionsRole")
-    def iot_actions_role(self) -> aws_cdk.aws_iam.Role:
-        return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "iotActionsRole"))
+    def iot_actions_role(self) -> _aws_cdk_aws_iam_ceddda9d.Role:
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.Role, jsii.get(self, "iotActionsRole"))
 
     @builtins.property
     @jsii.member(jsii_name="iotTopicRule")
-    def iot_topic_rule(self) -> aws_cdk.aws_iot.CfnTopicRule:
-        return typing.cast(aws_cdk.aws_iot.CfnTopicRule, jsii.get(self, "iotTopicRule"))
+    def iot_topic_rule(self) -> _aws_cdk_aws_iot_ceddda9d.CfnTopicRule:
+        return typing.cast(_aws_cdk_aws_iot_ceddda9d.CfnTopicRule, jsii.get(self, "iotTopicRule"))
 
     @builtins.property
     @jsii.member(jsii_name="kinesisStream")
-    def kinesis_stream(self) -> aws_cdk.aws_kinesis.Stream:
-        return typing.cast(aws_cdk.aws_kinesis.Stream, jsii.get(self, "kinesisStream"))
+    def kinesis_stream(self) -> _aws_cdk_aws_kinesis_ceddda9d.Stream:
+        return typing.cast(_aws_cdk_aws_kinesis_ceddda9d.Stream, jsii.get(self, "kinesisStream"))
 
     @builtins.property
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
-    ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]], jsii.get(self, "cloudwatchAlarms"))
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_cloudwatch_ceddda9d.Alarm]]:
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_cloudwatch_ceddda9d.Alarm]], jsii.get(self, "cloudwatchAlarms"))
 
 
 @jsii.data_type(
@@ -244,9 +234,9 @@ class IotToKinesisStreamsProps:
     def __init__(
         self,
         *,
-        iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
+        iot_topic_rule_props: typing.Union[_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, typing.Dict[builtins.str, typing.Any]],
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-        existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
+        existing_stream_obj: typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.Stream] = None,
         kinesis_stream_props: typing.Any = None,
     ) -> None:
         '''
@@ -258,22 +248,14 @@ class IotToKinesisStreamsProps:
         :summary: The properties for the IotToKinesisFirehoseToS3 Construct
         '''
         if isinstance(iot_topic_rule_props, dict):
-            iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(**iot_topic_rule_props)
+            iot_topic_rule_props = _aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps(**iot_topic_rule_props)
         if __debug__:
-            def stub(
-                *,
-                iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
-                kinesis_stream_props: typing.Any = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__d8d6186f38000ef686710547d8ce82a8a9598e193e4e1de49d82d813dc8c00c6)
             check_type(argname="argument iot_topic_rule_props", value=iot_topic_rule_props, expected_type=type_hints["iot_topic_rule_props"])
             check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
             check_type(argname="argument existing_stream_obj", value=existing_stream_obj, expected_type=type_hints["existing_stream_obj"])
             check_type(argname="argument kinesis_stream_props", value=kinesis_stream_props, expected_type=type_hints["kinesis_stream_props"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "iot_topic_rule_props": iot_topic_rule_props,
         }
         if create_cloud_watch_alarms is not None:
@@ -284,14 +266,14 @@ class IotToKinesisStreamsProps:
             self._values["kinesis_stream_props"] = kinesis_stream_props
 
     @builtins.property
-    def iot_topic_rule_props(self) -> aws_cdk.aws_iot.CfnTopicRuleProps:
+    def iot_topic_rule_props(self) -> _aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps:
         '''User provided CfnTopicRuleProps to override the defaults.
 
         :default: - Default props are used
         '''
         result = self._values.get("iot_topic_rule_props")
         assert result is not None, "Required property 'iot_topic_rule_props' is missing"
-        return typing.cast(aws_cdk.aws_iot.CfnTopicRuleProps, result)
+        return typing.cast(_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, result)
 
     @builtins.property
     def create_cloud_watch_alarms(self) -> typing.Optional[builtins.bool]:
@@ -303,13 +285,15 @@ class IotToKinesisStreamsProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def existing_stream_obj(self) -> typing.Optional[aws_cdk.aws_kinesis.Stream]:
+    def existing_stream_obj(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.Stream]:
         '''Existing instance of Kinesis Stream object, providing both this and KinesisStreamProps will cause an error.
 
         :default: - Default props are used
         '''
         result = self._values.get("existing_stream_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_kinesis.Stream], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.Stream], result)
 
     @builtins.property
     def kinesis_stream_props(self) -> typing.Any:
@@ -338,3 +322,25 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__d28904177b510423b390da5905611b385d14e1350614ba786f1ee2611f052b7b(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    iot_topic_rule_props: typing.Union[_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, typing.Dict[builtins.str, typing.Any]],
+    create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+    existing_stream_obj: typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.Stream] = None,
+    kinesis_stream_props: typing.Any = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d8d6186f38000ef686710547d8ce82a8a9598e193e4e1de49d82d813dc8c00c6(
+    *,
+    iot_topic_rule_props: typing.Union[_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, typing.Dict[builtins.str, typing.Any]],
+    create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+    existing_stream_obj: typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.Stream] = None,
+    kinesis_stream_props: typing.Any = None,
+) -> None:
+    """Type checking stubs"""
+    pass
